function[pend] = quadopt

% FILENAME:     QUAD_2003Nov14
% DESCRIPTION:  % Design of quad pendulum with blade spring optimisation
% VERSION NO:   QUAD file version 14

% NOTE:         filename format RM<year><month><date>.m
%               version number to be incremented plus date changed

%%**********************************************************************
%%COMMENTS%%
%% QUAD PENDULUM MODEL WITH CANTILEVERS AS SPRINGS 
%% see pendulum diagram for definitions of parameters
%% PARAMETERS FOR THE ETM QUAD
%% VERSION HAS NO LEVER_ARM INPUT
%%**********************************************************************

%****************************************************************************
% FILE LOG:
% Written by KAS  7/99                                              VERSION 00
% edited by CIT 11/99                                               VERSION 01
% changed again by KAS 12/99                                        VERSION 02
% changes to use structure 12/99 KAS                                VERSION 03
% with changes from real mass and moments from pmoment.m - Jan 02   VERSION 04
% with added block 26/Jan/02                                        VERSION 05
% Calum's/Mike's/Matts blade equations added 12/99 KAS              VERSION 06
% routine to optimise blades added 12/99 KAS                        VERSION 07
% pendulum updated 27/1/00 CIT & KAS                                VERSION 08
% updated with info from MB @ CIT                                   VERISON 09
% NAR April 2003                                                    VERSION 10
   % 23rd April working model for either sapphire or silica test mass NAR
%CIT May 07 2003                                                    VERSION 11
%CIT July 29 2003                                                    VERSION 12
    % Updated nn1 to fit MPL's layout and tln to include d's
%CIT/NAR Nov 13 2003 length changes after consideration of layout   VERSION 13
%NAR various mods for revised blades, updated masses, revised wire radii
                                                                    %VERSION 14
                                                                 
 
 %NAR silica parameters now chosen as default. May 05                                                                    
                                                                    
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%



% coordinates x = longitudinal = u_LIGO roll about this axis
%             y = transverse   = v_LIGO pitch about this axis
%             z = vertical     = w_LIGO yaw about this axis



%********************************************************************

% MASS (N) is REPRESENTED by a rectangular BLOCK

% in reality it will be larger and less dense.

global pend

 pend.g		= 9.81;
 %pend.nx	= 0.13;			%dimensions of MASS (N) (square)
 %pend.ny	= 0.50; 
 %pend.nz	= 0.084; 
 %pend.denn	= 4000;			%density (steel w holes)
 %pend.mn	= pend.denn* pend.ny* pend.nz* pend.nx;		%MASS (N) 

 %pend.Inx	=  pend.mn*( pend.ny^2+ pend.nz^2)/12;	%moment of inertia (transverse roll)
 %pend.Iny	=  pend.mn*( pend.nz^2+ pend.nx^2)/12;	%moment of inertia (longitudinal pitch)
 %pend.Inz	=  pend.mn*( pend.ny^2+ pend.nx^2)/12;	%moment of inertia (yaw)
 
 %updated using realistic values from MPL 17 Sept 2004 
 pend.mn	= 22.065;		%MASS (N)
 pend.Inx	=  0.47548;	%moment of inertia (transverse roll)
 pend.Iny	=  0.07086;	%moment of inertia (longitudinal pitch)
 pend.Inz	=  0.47635;	%moment of inertia (yaw)
 
 %further updated using values from MPL 29 Oct 2004 
 pend.mn	= 21.96;		%MASS (N)
 pend.Inx	=  0.4740;	%moment of inertia (transverse roll)
 pend.Iny	=  0.0704;	%moment of inertia (longitudinal pitch)
 pend.Inz	=  0.4754;	%moment of inertia (yaw)
 
 %further updated using vlaues from MPL in T040071-04-K 23 March 2005 (as built)
 pend.mn	= 22.11;		%MASS (N)
 pend.Inx	=  0.4558;	%moment of inertia (transverse roll)
 pend.Iny	=  0.0712;	%moment of inertia (longitudinal pitch)
 pend.Inz	=  0.4547;	%moment of inertia (yaw)


 %********************************************************************

% MASS (1) is REPRESENTED by a rectangular BLOCK

% in reality it will be larger and less dense.



 %pend.ux	= 0.13;			%dimensions MASS (1) (square)
 %pend.uy	= 0.50; 
 %pend.uz	= 0.084; 
 %pend.den1	= 4000;			%density (steel w holes)

 %pend.m1	= pend.den1* pend.uy* pend.uz* pend.ux	;	%MASS (1) 

 
 %pend.I1x	=  pend.m1*( pend.uy^2+ pend.uz^2)/12;	%moment of inertia (transverse roll)
 %pend.I1y	=  pend.m1*( pend.uz^2+ pend.ux^2)/12;	%moment of inertia (longitudinal pitch)
 %pend.I1z	=  pend.m1*( pend.uy^2+ pend.ux^2)/12;	%moment of inertia (yaw)

 % updated using values from MPL 29 Oct 2004 
  pend.m1	= 22.16;	%MASS (1) 

 
 pend.I1x	=  0.4921;	%moment of inertia (transverse roll)
 pend.I1y	=  0.0624;	%moment of inertia (longitudinal pitch)
 pend.I1z	=  0.4953;	%moment of inertia (yaw)

 %further updated using values from MPL 9 Dec 2004
  pend.m1	= 22.011;	%MASS (1) 

 
 pend.I1x	=  0.5174;	%moment of inertia (transverse roll)
 pend.I1y	=  0.0598;	%moment of inertia (longitudinal pitch)
 pend.I1z	=  0.5205;	%moment of inertia (yaw)





%ETM U-I Reaction Mass from MPL 9 Dec 2004
%Mass: 22.026Kg
%moments:-
%Lxx: 0.5138
%Lyy: 0.0599
%Lzz: 0.5185



%********************************************************************

 %pend.ix	= 0.13;			%dimension of MASS (2) (cylinder)
 %pend.ir	= 0.157;
 %pend.den2 = 3980; %sapphire
 
 

 
 % alternative for use with silica test mass
pend.ix	= 0.2;			%dimension of MASS (2) (cylinder)
pend.ir	= 0.17;
pend.den2 = 2200; %silica




 
 pend.m2	= pend.den2*pi* pend.ir^2* pend.ix;		%MASS (2)
 
  pend.m2		= 39.6;	%corrected for flats Mar05

 pend.I2x	= pend.m2*(pend.ir^2/2);				%moment of inertia (transverse roll)
 pend.I2y	= pend.m2*(pend.ir^2/4+pend.ix^2/12);	%moment of inertia (longitudinal pitch)
 pend.I2z	= pend.m2*(pend.ir^2/4+pend.ix^2/12);	%moment of inertia (yaw)
%--------------
  % SF4 alternative (density 4790, assumed to have central hole to make mass 40kg)
%pend.ix	= 0.13;			%dimension of MASS (2) (cylinder)
%pend.ir	= 0.157;
%pend.den2 = 4790; %SF4

 %pend.m2	= 40;		%MASS (2)

 %pend.I2x	= 0.345;				%moment of inertia (transverse roll)
 %pend.I2y	= 0.331;	%moment of inertia (longitudinal pitch)
 %pend.I2z	= 0.564;	%moment of inertia (yaw)
% moments of inertia calculated by CIT Mar 04, assuming ~ 5inch diam central hole
%-----------------------
   %SF2 alternative (density 3860 - therefore lighter mass, 38.9kg)
%pend.ix	= 0.13;			%dimension of MASS (2) (cylinder)
%pend.ir	= 0.157;
%pend.den2 = 3860; %SF2

 %pend.m2	= pend.den2*pi* pend.ir^2* pend.ix;		%MASS (2)
 %pend.m2 = 38.4; %to allow for flats on sides

 %pend.I2x	= pend.m2*(pend.ir^2/2);				%moment of inertia (transverse roll)
%pend.I2y	= pend.m2*(pend.ir^2/4+pend.ix^2/12);	%moment of inertia (longitudinal pitch)
%pend.I2z	= pend.m2*(pend.ir^2/4+pend.ix^2/12);	%moment of inertia (yaw)
 




%*********************************************************************

 %pend.tx		= 0.13;			%dimensions of MASS (3) (cylinder)
 %pend.tr		= 0.157;
 %pend.den3	= 3980;			%density (sapphire)
 
  % alternative silica test mass
pend.tx		= 0.2;			%dimensions of MASS (3) (cylinder)
pend.tr		= 0.17;
pend.den3	= 2200;			%density (silica)
 
 pend.m3		= pend.den3*pi*pend.tr^2*pend.tx;	%MASS (3) 
 pend.m3		= 39.6;	%corrected for flats Mar05

 pend.I3x	= pend.m3*(pend.tr^2/2);				%moment of inertia (transverse roll)
 pend.I3y	= pend.m3*(pend.tr^2/4+pend.tx^2/12);	%moment of inertia (longitudinal pitch)
 pend.I3z	= pend.m3*(pend.tr^2/4+pend.tx^2/12);	%moment of inertia (yaw)

 %sapphire mass including 95mm flats see T040013-00-D no 1
  %pend.m3		= 39.61;	%MASS (3) 


 %pend.I3x	= 0.483;				%moment of inertia (transverse roll)
 %pend.I3y	= 0.302;	%moment of inertia (longitudinal pitch)
 %pend.I3z	= 0.292;	%moment of inertia (yaw)
 
  %test mass  alu +steel including 95mm flats see T040013-00-D no 2
  %pend.m3		= 39.629;	%MASS (3) 


 %pend.I3x	= 0.473;				%moment of inertia (transverse roll)
 %pend.I3y	= 0.280;	%moment of inertia (longitudinal pitch)
 %pend.I3z	= 0.279;	%moment of inertia (yaw)
 
   %test mass  alu +steel +BK7 including 95mm flats see T040013-00-D no 3
  %pend.m3		= 39.627;	%MASS (3) 


 %pend.I3x	= 0.465;			%moment of inertia (transverse roll)
 %pend.I3y	= 0.276;	%moment of inertia (longitudinal pitch)
 %pend.I3z	= 0.275;	%moment of inertia (yaw)

%********************************************************************

%pend.ln = 0.54;    	%wire length 1: short version
pend.ln = 0.445;        % CIT/NAR Nov 2003 reduced as per requirement from SEI to meet overall length 200.5 cm
pend.l1	= 0.304;		%wire length 2: short version

pend.l1	= 0.3085 ;%new value July 04, to aid in fitting blades, see n1, see MPL e-mails

%pend.l2	= 0.302;		%wire length 3: short version
%pend.l2	= 0.342;        %CIT/NAR Nov 2003 longer length for ease of assembly of masses
%pend.l2	= 0.34;        %alternative to use if n2 changed from 12 to 14 cm, overall length same,NAR April 04
%pend.l2	= 0.344; % alternate for silica to get same length to centre of mass of optic
pend.l2	= 0.341; % alternate for silica adjusted to go with new l1 above, Mar 05
pend.l3	= 0.6;	    	%wire length 4  

%******************************************************************************************

 pend.nwn	= 2; %number of wires (= number of cantilevers if fitted) per stage (2 or 4)
 pend.nw1	= 4;			
 pend.nw2	= 4;
 pend.nw3	= 4;

%***********************************************************************************

 
 pend.rn	= 460e-6;	%radius of wire (N) % approx scaled from that used in MIT model
 pend.r1	= 320e-6;	%radius of wire (1) % approx scaled from that used in MIT model
 pend.r2	= 320e-6;	%radius of wire (2) % approx scaled from that used in MIT model
 pend.r3	= 200e-6;	%radius of wire (3) % same as conceptual design
 
 %new wire radii for better safety
 pend.rn	= 700e-6;	%radius of wire (N) % factor of 5 safety
 pend.r1	= 400e-6;	%radius of wire (1) %factor of 4 safety
 pend.r2	= 350e-6;	%radius of wire (2) % factor of 4 safety
 pend.r3	= 200e-6;	%radius of wire (3) % same as conceptual design
 
 
  %revised wire radii for smaller bending distancc, Feb 04, b. stress 2e9
 pend.rn	= 540e-6;	%radius of wire (N) % factor of 3 safety
 pend.r1	= 350e-6;	%radius of wire (1) %factor of 3 safety
 pend.r2	= 310e-6;	%radius of wire (2) % factor of 3 safety
 pend.r3	= 200e-6;	%radius of wire (3) % same as conceptual design
 
 %try slightly thicker for ease of manufacture for clamping Nov 11,2004
  %pend.rn	= 600e-6;	%radius of wire (N) 
 %pend.r1	= 400e-6;	%radius of wire (1) 
 %pend.r2	= 350e-6;	%radius of wire (2) 
 
 
 
  %pend.r3	= 220e-6;	%radius of wire (3) for T040013-00-D parameter set 2,3, safety factor 3

%************************************************************************************

 %pend.Yn  	= 1.65e11;	%Youngs Modulus of wire	(N)	(s/steel 302)
 %pend.Y1	= 1.65e11;	%Youngs Modulus of wire	(1)	(s/steel 302)
 %pend.Y2	= 1.65e11;	%Youngs Modulus of wire (2)	(s/steel 302)
 
 pend.Yn  	= 2.2e11;	%consistent w/ measurements at Caltech
 pend.Y1	= 2.2e11;	
 pend.Y2	= 2.2e11;	

 pend.Y3	= 7e10;		%Youngs Modulus of wire	(3)	(fused silica)
 %pend.Y3 = 2.2e11;     %T040013-00-D parameter set no 2,3 for alu/steel mass
 %blade design

 mntb = (pend.mn+pend.m1+pend.m2+pend.m3)/2;%total per blade
 mnb  = pend.mn/2;%uncoupled mass

[uf,lnb,anb,hnb,stn] = opt(mnb,mntb,9e8,0.48,0.10); 

[uf,lnb,anb,hnb,stn] = opt(mnb,mntb,10e8,0.48,0.095); %alternate with larger stress, Mar04

 %pend.lnb = lnb;
 %pend.anb = anb;
 %pend.hnb = hnb;
 %pend.ufcn = uf;
 %pend.stn  = stn;
 %pend.intmode_n = 55*hnb*0.37^2/(0.002*lnb^2); %scaled from GEO blade
 
%pend.ufcn = 2.36; %override, value as in concept. design
%pend.ufcn = 2.33; %override length 48 cm width 9.5 cm, thickness 4.3 mm, alpha 1.35, NAR Apr04
pend.ufcn = 2.33; %override length 48 cm width 9.5 cm, thickness 4.3 mm, alpha 1.35, 
                    %NAR Mar 05, using silica masses

 %blade design

 m1tb = (pend.m1+pend.m2+pend.m3)/2;%total per blade
 m1b  = pend.m1/2;%uncoupled mass
[uf,l1b,a1b,h1b,st1] = opt(m1b,m1tb,9e8,0.42,0.06); 
 [uf,l1b,a1b,h1b,st1] = opt(m1b,m1tb,10e8,0.42,0.06);%alternate with larger stress, Mar04
 
 %pend.l1b = l1b;
 %pend.a1b = a1b;
 %pend.h1b = h1b;
 %pend.ufc1 = uf;
 %pend.st1  = st1;
 %pend.intmode_1 = 55*h1b*0.37^2/(0.002*l1b^2); %scaled from GEO blade

 
%pend.ufc1 = 2.56; %override, value as in concept. design
%pend.ufc1 = 2.48; %override length 42 cm, width 5.9 cm thickness 4.6 mm, alpha 1.35 NAR April 04
pend.ufc1 = 2.48; %override length 42 cm, width 5.9 cm thickness 4.6 mm, alpha 1.35 
                    %NAR Mar 05, using silica masses
 
%blade design

 m2tb = (pend.m2+pend.m3)/2;%total per blade
 m2b  = pend.m2/2;%uncoupled mass
 [uf,l2b,a2b,h2b,st2] = opt(m2b,m2tb,8e8,0.35,0.05); %35cm currently in layouts MAr 04
 
  [uf,l2b,a2b,h2b,st2] = opt(m2b,m2tb,10e8,0.37,0.05); 
 % alternative longer blade and higher stress Mar04

 %pend.l2b = l2b;
 %pend.a2b = a2b;
 %pend.h2b = h2b;
 %pend.ufc2 = uf;
 %pend.st2  = st2;
 %pend.intmode_2 = 55*h2b*0.37^2/(0.002*l2b^2); %scaled from GEO blade
 
  %pend.ufc2 = 2.11; %override, value as in concept. design
 %pend.ufc2 = 1.81; %override length 37 cm, width 4.9 cm, thickness 4.2 mm, alpha 1.35 NAR Apr 04
 pend.ufc2 = 1.78; %override length 37 cm, width 4.9 cm, thickness 4.2 mm, alpha 1.35 
                    %NAR Mar 05 , using silica masses
%****************************************************************************************

%dees = 0.001;

pend.dm		= 0.001;	%height of wire break-off above c.of m. mass (N)
pend.dn		= 0.001;	%height of wire break-off below c.of m. mass (N)
pend.d0		= 0.001;	%height of wire break-off above c.of m. mass (1)
pend.d1		= 0.001;	%height of wire break-off below c.of m. mass (1)

pend.d2		= 0.001;	%height of wire break-off above c.of m. mass (2)
pend.d3		= 0.001;	%height of wire break-off below c.of m. mass (2)
pend.d4		= 0.001;	%height of wire break-off above c.of m. mass (3)



% note: "break-off" height is from effective flexure point to c. of m. plane

%additional information for ribbon breakoffs

%these are needed in translation/roll mode calculations

pend.twistlength = 0.00; %length of twist section in ribbon
pend.d3tr = pend.d3 - pend.twistlength;
pend.d4tr = pend.d4 - pend.twistlength;

%******************************************************************************************

%X direction separation 

pend.sn	= 0.00;		%1/2 separation of wires (N)   
pend.su	= 0.003;		%1/2 separation of wires (1) 
pend.si	= 0.003;		%1/2 separation of wires (2)
pend.sl	= 0.008;		%1/2 separation of wires (3) 
pend.sl	= 0.015;		%1/2 separation of wires (3) larger for ear design Jan/Feb04
%******************************************************************************************

%Y direction separation

pend.nn0 = 0.25;   	%1/2 separation of wires (N) at suspension point

%pend.nn1 = 0.12; %1/2 separation of wires (N) at mass (N), value preferred for mechanical fitting
%pend.nn1 = 0.11; % for better mech fit 30apr
pend.nn1 = 0.09; % MPL 28th May 2003 request for smaller separation

pend.n0	= 0.2;		%1/2 separation of wires (1) at mass (N)
pend.n1 = 0.07;
pend.n1 = 0.06; %new value July 04, to aid in fitting blades, see MPL e-mails
pend.n2 = 0.12;

pend.n2 = 0.14; %try this to accommodate larger blades Apr 2004, NAR (sse also l2 above)

pend.n3	=pend.ir+0.0065;	%1/2 separation of wires (2) at mass (2)  
pend.n4	=pend.tr+0.0015;	%1/2 separation of wires (3) at mass (2)  
pend.n5	=pend.tr+0.0015;	%1/2 separation of wires (3) at mass (3)

% try different values to check if a ~4mm ear would work -CAC request MAR 05
%pend.n3	=pend.ir+0.002;	%1/2 separation of wires (2) at mass (2)  
%pend.n4	=pend.tr-0.003;	%1/2 separation of wires (3) at mass (2)  
%pend.n5	=pend.tr-0.003;	%1/2 separation of wires (3) at mass (3)

% currently CAC planning 8 mm ear for ribbon  - giving set as below. MAr 05
pend.n3	=pend.ir+0.0062;	%1/2 separation of wires (2) at mass (2)  
pend.n4	=pend.tr+0.0012;	%1/2 separation of wires (3) at mass (2)  
pend.n5	=pend.tr+0.0012;	%1/2 separation of wires (3) at mass (3)


%pend.n4	=0.158;	%1/2 separation of wires (3) at mass (2) %T040013-00-D parameter set no 2  
%pend.n5	=0.158;	%1/2 separation of wires (3) at mass (3)%T040013-00-D parameter set no 2 

% values for use in controls prototype see CITe-mail 22Sept04
%pend.n3      = 0.164 
%pend.n4      = 0.158 
%pend.n5      = 0.158 (or 161mm in the reaction chain for "break-off" instead of a clamp)   

%now we can work out the true lengths com to com etc.
%CIT July 29th 2003 Updated to inclde the d's in the individual tl# 

pend.tln = sqrt(pend.ln^2 - (pend.nn0-pend.nn1)^2) + pend.dm;
pend.tl1 = sqrt(pend.l1^2 - (pend.n0-pend.n1)^2) + pend.dn + pend.d0;
pend.tl2 = sqrt(pend.l2^2 - (pend.n2-pend.n3)^2) + pend.d1 + pend.d2;
pend.tl3 = sqrt(pend.l3^2 - (pend.n4-pend.n5)^2) + pend.d3 + pend.d4;

% Distance to the centre of mass from suspension point 
pend.l_suspoint_to_centreofoptic  =  pend.tln +pend.tl1+pend.tl2+pend.tl3;

% Distance to the bottom of the test mass from suspension point 
pend.l_suspoint_to_bottomofoptic  =  pend.tln +pend.tl1+pend.tl2+pend.tl3+pend.tr;

%***********************************************************************************

% represents small loss

pend.bd = 0.00; % makes phases of open loop plots look nicer

%*********************************************************************************** 

%mean distances of actuators from axis of rotation
% no longer called

%pend.lever_pitch	= 0.06;
%pend.lever_pitch	= 0.055; alternate value
%pend.lever_yaw   = 0.12;
%pend.lever_roll	= 0.15;
%pend.lever_roll	= 0.16; alternate value

%IMPORTANT FOR REFERENCE ONLY!!!
%Gain triangles in pende.m

%gain   = -1.2;

%Gain triangle = (leverarm)^2 * (no. of coils) * gain

%***Note that gains are linked in different directions due to common coils as below*****
%***If gains in one channel only need to be changed then leverarm can be used***********

%gainzrtrl =gain;	% vertical, z, pitch, rt, roll rl (coils on top of upper mass)
%gaint   = gain.*2;	% transverse, t (coil on one end of upper mass)
%gainlrz = gain;		% longitudinal, l, yaw, rz (coils on long rear side of upper mass) 


%long   = (1)^2    *  2 * gainlrz    = -2.4 
%pitch  = (0.06)^2 *  2 * gainzrtrl    = -8.64e-3, alternate value = -7.26e-3 with pitch 0.055
%vert   = (1)^2    *  3 * gainzrtrl    = -3.6
%yaw    = (0.12)^2 *  2 * gainlrz    = -2.88e-2 note this is for for gain = 1, superceded
%trans  = (1)^2    *  1 * gaint   = -2.4
%roll   = (0.15)^2 *  3 * gainzrtrl    =  -8.1e-2, alternate value = -9.216e-2 with roll 0.16

% New values of gains to reflect different numbers of OSEMs and values of lever arms
%From C Torrie e-mail 26 Feb 04

%gain   = -1.2;

%Gain triangle = (leverarm)^2 * (no. of coils) * gain

%***Note that gains are linked in different directions due to common coils as below*****
%***If gains in one channel only need to be changed then leverarm can be used***********

%gainzrtrl =gain;	% vertical, z, pitch, rt, roll rl (coils on top of upper mass)
%gaint   = gain.*2;	% transverse, t (coil on one end of upper mass)
%gainlrz = gain;		% longitudinal, l, yaw, rz (coils on long rear side of upper mass) 


%long   = (1)^2    *  3 * gainlrz    = -3.6 
%pitch  = (0.055)^2 *  3 * gainzrtrl    = 1.089e-2
%vert   = (1)^2    *  2 * gainzrtrl    = -2.4
%yaw    = (0.12)^2 *  2 * gainlrz    = -3.456e-2
%trans  = (1)^2    *  1 * gaint   = -2.4
%roll   = (0.16)^2 *  2 * gainzrtrl    =  -6.144e-2, or alternate vlaue arm = 0.18, 7.776e-2

%Further updated on number of OSEMS and leverarms. Gain triangles changed to reflect these.
%from telecon on 29th Oct 04 with CIT and MPL 

%long   = (1)^2    *  3 * gainlrz    = -3.6 
%pitch  = (0.11)^2 *  1 * gainzrtrl    = 1.452e-2
%vert   = (1)^2    *  2 * gainzrtrl    = -2.4
%yaw    = (0.12)^2 *  2 * gainlrz    = -3.456e-2
%trans  = (1)^2    *  1 * gaint   = -2.4
%roll   = (0.16)^2 *  2 * gainzrtrl    =  -6.144e-2,
%end

%VIEWER PREFERENCES (under edit on LTI viewer)

%UNITS
%Frequency in Hz using Log scale
%Magnitude in absolute using log scale
%Phase in degrees


%TIME VECTOR
%[0:0.01:50]

%FREQUENCY VECTOR
%logspace(-0.5,1.5,500)